# Multiline Commit Test

This file exists to test release note generation with commits that have multiple lines in their commit messages.

- This bullet will help test point 1
- Another bullet for release note parsing

Release notes now group repeated gitmoji entries under a single header, keeping lists concise.
